searchData={"items":[{"type":"module","title":"StructureSqlFormatter","doc":"","ref":"StructureSqlFormatter.html"},{"type":"function","title":"StructureSqlFormatter.format/2","doc":"Formats `structure.sql` to make the git diff easier to read.","ref":"StructureSqlFormatter.html#format/2"},{"type":"function","title":"Options - StructureSqlFormatter.format/2","doc":"The StructureSqlFormatter options are:\n\n* `:remove_trailing_whitespace` (`t:boolean/0`) - Remove trailing whitespace. The default value is `true`.\n\n* `:remove_version_specific_output` (`t:boolean/0`) - Don't output the postgres version used in the dump. Also remove some specific queries for different versions. The default value is `true`.\n\n* `:remove_useless_comment_lines` (`t:boolean/0`) - Remove `--` comments. The default value is `true`.\n\n* `:remove_pg_stat_statements_extension` (`t:boolean/0`) - Remove pg_stat_statements extension (its not relevant to the code). The default value is `true`.\n\n* `:remove_pg_buffercache_extension` (`t:boolean/0`) - Remove pg_buffercache extension (its not relevant to the code). The default value is `true`.\n\n* `:remove_comments_on_extensions` (`t:boolean/0`) - Remove `COMMENT ON EXTENSION` parts. The default value is `true`.\n\n* `:remove_useless_version_specific_parts_of_comments` (`t:boolean/0`) - Remove `Schema: xxx; Owner; yyy` parts. The default value is `true`.\n\n* `:reduce_noise_for_id_fields` (`t:boolean/0`) - Reduce noise for id fields by making them SERIAL instead of integer+sequence stuff.\n  This is a bit optimistic, but works as long as you don't have an id field thats not a sequence/uuid. The default value is `false`.\n\n* `:remove_inherited_tables` (`t:boolean/0`) - Remove inherited tables. The default value is `false`.\n\n* `:remove_partitioned_tables` (`t:boolean/0`) - Remove partitioned tables. The default value is `false`.\n\n* `:allow_restoring_postgres_11_output_on_postgres_10` (`t:boolean/0`) - Makes dump from postgres 11 compatible for postgres 10. The default value is `true`.\n\n* `:order_schema_migrations_values` (`t:boolean/0`) - Cleanup of schema_migrations values to prevent merge conflicts:\n  - sorts all values chronological\n  - places the comma's in front of each value (except for the first)\n  - places the semicolon on a separate last line The default value is `false`.","ref":"StructureSqlFormatter.html#format/2-options"},{"type":"extras","title":"StructureSqlFormatter","doc":"# StructureSqlFormatter\n\nEver been annoyed at a constantly changing `priv/repo/structure.sql` file when using Ecto and Postgres?\n\nSpent hours trying to decipher why that one team member keeps changing the file?\n\nThis library is here to help!\n\nIt cleans away all the unnecessary output in the file every time you run `mix format`. This helps avoid merge conflicts, as well as increase readability.\n\nI took inspiration from [activerecord-clean-db-structure](https://github.com/lfittl/activerecord-clean-db-structure) and reimplemented the logic in Elixir.","ref":"readme.html"},{"type":"extras","title":"Installation - StructureSqlFormatter","doc":"The package can be installed by adding `structure_sql_formatter` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:structure_sql_formatter, \"~> 1.0.0\", only: :dev}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - StructureSqlFormatter","doc":"Uses Elixir formatter [plugin\nsystem](https://hexdocs.pm/mix/1.16.3/Mix.Tasks.Format.html#module-plugins).\n\n```elixir\n# .formatter.exs\n[\n  plugins: [StructureSqlFormatter],\n  # See `StructureSqlFormatter.Options` for all available options.\n  structure_sql_formatter_opts: [\n    order_schema_migrations_values: true\n  ],\n  inputs: [\"{mix,.formatter}.exs\", \"{config,lib,test}/**/*.{ex,exs}\", \"priv/repo/structure.sql\"]\n]\n```\n\nRunning `mix format` is going to take over as usual from here.","ref":"readme.html#usage"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"1.0.2 - 2024-05-26 - Changelog","doc":"* Fix source link in docs.","ref":"changelog.html#1-0-2-2024-05-26"},{"type":"extras","title":"1.0.1 - 2024-05-26 - Changelog","doc":"* Fix for `Schema: -; Owner: -`. Sometimes it was not removed.","ref":"changelog.html#1-0-1-2024-05-26"},{"type":"extras","title":"1.0.0 - 2024-05-26 - Changelog","doc":"* Initial release","ref":"changelog.html#1-0-0-2024-05-26"},{"type":"extras","title":"LICENSE","doc":"Copyright (c) 2024-present Aleksandr Lossenko\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,51,46,48]}}